# ListUpstreamUserIdentitiesResponse

Response object for upstream user identity query
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**upstream_user_identities** | [**list[UpstreamUserIdentity]**](UpstreamUserIdentity.md) | The matching UpstreamUserIdentity objects | 
**limit** | **int** | Limit on the number of rows in the response | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


